@@ -19,10 +19,14 @@
 
 package org.apache.parquet.cli.commands;
 
+import static org.apache.parquet.format.converter.ParquetMetadataConverter.NO_FILTER;
+
 import com.beust.jcommander.Parameter;
 import com.beust.jcommander.Parameters;
 import com.google.common.base.Preconditions;
 import com.google.common.collect.Lists;
+import java.io.IOException;
+import java.util.List;
 import org.apache.hadoop.fs.Path;
 import org.apache.parquet.HadoopReadOptions;
 import org.apache.parquet.cli.BaseCommand;
@@ -36,13 +40,10 @@ import org.apache.parquet.hadoop.util.HadoopInputFile;
 import org.apache.parquet.schema.MessageType;
 import org.slf4j.Logger;
 
-import java.io.IOException;
-import java.util.List;
-
-import static org.apache.parquet.format.converter.ParquetMetadataConverter.NO_FILTER;
-
-@Parameters(commandDescription="(Deprecated: will be removed in 2.0.0, use rewrite command instead) " +
-        "Replace columns with masked values and write to a new Parquet file")
+@Deprecated
+@Parameters(
+    commandDescription = "(Deprecated: will be removed in 2.0.0, use rewrite command instead) "
+        + "Replace columns with masked values and write to a new Parquet file")
 public class ColumnMaskingCommand extends BaseCommand {
 
   private ColumnMasker masker;
@@ -53,40 +54,39 @@ public class ColumnMaskingCommand extends BaseCommand {
   }
 
   @Parameter(
-    names = {"-m", "--mode"},
-    description = "<mask mode: nullify>",
-    required = true)
+      names = {"-m", "--mode"},
+      description = "<mask mode: nullify>",
+      required = true)
   String mode;
 
   @Parameter(
-    names = {"-i", "--input"},
-    description = "<input parquet file path>",
-    required = true)
+      names = {"-i", "--input"},
+      description = "<input parquet file path>",
+      required = true)
   String input;
 
   @Parameter(
-    names = {"-o", "--output"},
-    description = "<output parquet file path>",
-    required = true)
+      names = {"-o", "--output"},
+      description = "<output parquet file path>",
+      required = true)
   String output;
 
   @Parameter(
-    names = {"-c", "--columns"},
-    description = "<columns to be replaced with masked value>",
-    required = true)
+      names = {"-c", "--columns"},
+      description = "<columns to be replaced with masked value>",
+      required = true)
   List<String> cols;
 
   @Override
   @SuppressWarnings("unchecked")
   public int run() throws IOException {
-    Preconditions.checkArgument(mode != null && (mode.equals("nullify")),
-      "mask mode cannot be null and can be only nullify");
+    Preconditions.checkArgument(
+        mode != null && (mode.equals("nullify")), "mask mode cannot be null and can be only nullify");
 
-    Preconditions.checkArgument(input != null && output != null,
-      "Both input and output parquet file paths are required.");
+    Preconditions.checkArgument(
+        input != null && output != null, "Both input and output parquet file paths are required.");
 
-    Preconditions.checkArgument(cols != null && cols.size() > 0,
-      "columns cannot be null or empty");
+    Preconditions.checkArgument(cols != null && !cols.isEmpty(), "columns cannot be null or empty");
 
     MaskMode maskMode = MaskMode.fromString(mode);
     Path inPath = new Path(input);
@@ -97,7 +97,9 @@ public class ColumnMaskingCommand extends BaseCommand {
     ParquetFileWriter writer = new ParquetFileWriter(getConf(), schema, outPath, ParquetFileWriter.Mode.CREATE);
     writer.start();
 
-    try (TransParquetFileReader reader = new TransParquetFileReader(HadoopInputFile.fromPath(inPath, getConf()), HadoopReadOptions.builder(getConf()).build())) {
+    try (TransParquetFileReader reader = new TransParquetFileReader(
+        HadoopInputFile.fromPath(inPath, getConf()),
+        HadoopReadOptions.builder(getConf()).build())) {
       masker.processBlocks(reader, writer, metaData, schema, cols, maskMode);
     } finally {
       writer.end(metaData.getFileMetaData().getKeyValueMetaData());
@@ -109,7 +111,6 @@ public class ColumnMaskingCommand extends BaseCommand {
   public List<String> getExamples() {
     return Lists.newArrayList(
         "# Replace columns with masked values and write to a new Parquet file",
-        "-m nullify -i input.parquet -o output.parquet -c col1_name"
-    );
+        "-m nullify -i input.parquet -o output.parquet -c col1_name");
   }
 }
