@@ -20,16 +20,14 @@ package org.apache.parquet.internal.column.columnindex;
 
 import static java.nio.ByteOrder.LITTLE_ENDIAN;
 
+import it.unimi.dsi.fastutil.floats.FloatArrayList;
+import it.unimi.dsi.fastutil.floats.FloatList;
 import java.nio.ByteBuffer;
-
 import org.apache.parquet.filter2.predicate.Statistics;
 import org.apache.parquet.io.api.Binary;
 import org.apache.parquet.schema.PrimitiveComparator;
 import org.apache.parquet.schema.PrimitiveType;
 
-import it.unimi.dsi.fastutil.floats.FloatArrayList;
-import it.unimi.dsi.fastutil.floats.FloatList;
-
 class FloatColumnIndexBuilder extends ColumnIndexBuilder {
   private static class FloatColumnIndex extends ColumnIndexBase<Float> {
     private float[] minValues;
@@ -152,4 +150,9 @@ class FloatColumnIndexBuilder extends ColumnIndexBuilder {
   int sizeOf(Object value) {
     return Float.BYTES;
   }
+
+  @Override
+  public long getMinMaxSize() {
+    return (long) minValues.size() * Float.BYTES + (long) maxValues.size() * Float.BYTES;
+  }
 }
