@@ -19,9 +19,26 @@
 
 package org.apache.parquet.crypto.propertiesfactory;
 
+import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.BINARY;
+import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT64;
+import static org.apache.parquet.schema.Type.Repetition.OPTIONAL;
+import static org.apache.parquet.schema.Type.Repetition.REPEATED;
+import static org.apache.parquet.schema.Type.Repetition.REQUIRED;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+
+import java.io.IOException;
+import java.nio.file.Files;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Random;
+import java.util.concurrent.ThreadLocalRandom;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.parquet.column.ColumnDescriptor;
+import org.apache.parquet.conf.HadoopParquetConfiguration;
+import org.apache.parquet.conf.ParquetConfiguration;
 import org.apache.parquet.crypto.EncryptionPropertiesFactory;
 import org.apache.parquet.crypto.ParquetCipher;
 import org.apache.parquet.example.data.Group;
@@ -39,29 +56,14 @@ import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.IOException;
-import java.nio.file.Files;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Random;
-import java.util.concurrent.ThreadLocalRandom;
-
-import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.BINARY;
-import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT64;
-import static org.apache.parquet.schema.Type.Repetition.OPTIONAL;
-import static org.apache.parquet.schema.Type.Repetition.REPEATED;
-import static org.apache.parquet.schema.Type.Repetition.REQUIRED;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-
 public class SchemaControlEncryptionTest {
 
-  private final static Logger LOG = LoggerFactory.getLogger(SchemaControlEncryptionTest.class);
-  private final static int numRecord = 1000;
+  private static final Logger LOG = LoggerFactory.getLogger(SchemaControlEncryptionTest.class);
+  private static final int numRecord = 1000;
   private Random rnd = new Random(5);
 
-  // In the test We use a map to tell WriteSupport which columns to be encrypted with what key. In real use cases, people
+  // In the test We use a map to tell WriteSupport which columns to be encrypted with what key. In real use cases,
+  // people
   // can find whatever easy way to do so basing on how do they get these information, for example people can choose to
   // store in HMS, or other metastore.
   private Map<String, Map<String, Object>> cryptoMetadata = new HashMap<>();
@@ -113,9 +115,10 @@ public class SchemaControlEncryptionTest {
     runTest(conf);
   }
 
-  private void runTest(Configuration conf ) throws Exception {
-    conf.set(EncryptionPropertiesFactory.CRYPTO_FACTORY_CLASS_PROPERTY_NAME,
-      SchemaCryptoPropertiesFactory.class.getName());
+  private void runTest(Configuration conf) throws Exception {
+    conf.set(
+        EncryptionPropertiesFactory.CRYPTO_FACTORY_CLASS_PROPERTY_NAME,
+        SchemaCryptoPropertiesFactory.class.getName());
     String file = createTempFile("test");
     markEncryptColumns();
     encryptParquetFile(file, conf);
@@ -133,26 +136,29 @@ public class SchemaControlEncryptionTest {
   }
 
   private String encryptParquetFile(String file, Configuration conf) throws IOException {
-    MessageType schema = new MessageType("schema",
-      new PrimitiveType(REQUIRED, BINARY, "Name"),
-      new PrimitiveType(REQUIRED, INT64, "Age"),
-      new GroupType(OPTIONAL, "WebLinks",
-        new PrimitiveType(REPEATED, BINARY, "LinkedIn"),
-        new PrimitiveType(REPEATED, BINARY, "Twitter")));
+    MessageType schema = new MessageType(
+        "schema",
+        new PrimitiveType(REQUIRED, BINARY, "Name"),
+        new PrimitiveType(REQUIRED, INT64, "Age"),
+        new GroupType(
+            OPTIONAL,
+            "WebLinks",
+            new PrimitiveType(REPEATED, BINARY, "LinkedIn"),
+            new PrimitiveType(REPEATED, BINARY, "Twitter")));
 
     conf.set(GroupWriteSupport.PARQUET_EXAMPLE_SCHEMA, schema.toString());
     Path path = new Path(file);
     Builder builder = new Builder(path);
     builder.withConf(conf);
 
-   try (ParquetWriter writer = builder.build()) {
+    try (ParquetWriter writer = builder.build()) {
       for (int i = 0; i < 1000; i++) {
         SimpleGroup g = new SimpleGroup(schema);
-        g.add("Name", (String)testData.get("Name")[i]);
-        g.add("Age", (Long)testData.get("Age")[i]);
+        g.add("Name", (String) testData.get("Name")[i]);
+        g.add("Age", (Long) testData.get("Age")[i]);
         Group links = g.addGroup("WebLinks");
-        links.add(0, (String)testData.get("LinkedIn")[i]);
-        links.add(1, (String)testData.get("Twitter")[i]);
+        links.add(0, (String) testData.get("LinkedIn")[i]);
+        links.add(1, (String) testData.get("Twitter")[i]);
         writer.write(g);
       }
     }
@@ -161,15 +167,19 @@ public class SchemaControlEncryptionTest {
   }
 
   private void decryptParquetFileAndValid(String file, Configuration conf) throws IOException {
-    ParquetReader<Group> reader = ParquetReader.builder(new GroupReadSupport(), new Path(file)).withConf(conf).build();
+    ParquetReader<Group> reader = ParquetReader.builder(new GroupReadSupport(), new Path(file))
+        .withConf(conf)
+        .build();
     for (int i = 0; i < numRecord; i++) {
       Group group = reader.read();
       assertEquals(testData.get("Name")[i], group.getBinary("Name", 0).toStringUsingUTF8());
       assertEquals(testData.get("Age")[i], group.getLong("Age", 0));
 
       Group subGroup = group.getGroup("WebLinks", 0);
-      assertArrayEquals(subGroup.getBinary("LinkedIn", 0).getBytes(), ((String)testData.get("LinkedIn")[i]).getBytes());
-      assertArrayEquals(subGroup.getBinary("Twitter", 0).getBytes(), ((String)testData.get("Twitter")[i]).getBytes());
+      assertArrayEquals(
+          subGroup.getBinary("LinkedIn", 0).getBytes(), ((String) testData.get("LinkedIn")[i]).getBytes());
+      assertArrayEquals(
+          subGroup.getBinary("Twitter", 0).getBytes(), ((String) testData.get("Twitter")[i]).getBytes());
     }
     reader.close();
   }
@@ -203,6 +213,11 @@ public class SchemaControlEncryptionTest {
 
     @Override
     public WriteContext init(Configuration conf) {
+      return init(new HadoopParquetConfiguration(conf));
+    }
+
+    @Override
+    public WriteContext init(ParquetConfiguration conf) {
       WriteContext writeContext = super.init(conf);
       MessageType schema = writeContext.getSchema();
       List<ColumnDescriptor> columns = schema.getColumns();
@@ -219,12 +234,20 @@ public class SchemaControlEncryptionTest {
     }
 
     private void setMetadata(ColumnDescriptor column, Configuration conf) {
+      setMetadata(column, new HadoopParquetConfiguration(conf));
+    }
+
+    private void setMetadata(ColumnDescriptor column, ParquetConfiguration conf) {
       String columnShortName = column.getPath()[column.getPath().length - 1];
-      if (cryptoMetadata.containsKey(columnShortName) &&
-        cryptoMetadata.get(columnShortName).get("columnKeyMetaData") != null) {
+      if (cryptoMetadata.containsKey(columnShortName)
+          && cryptoMetadata.get(columnShortName).get("columnKeyMetaData") != null) {
         String columnKey = String.join(".", column.getPath());
-        conf.set(SchemaCryptoPropertiesFactory.PATH_NAME_PREFIX + columnKey,
-          cryptoMetadata.get(columnShortName).get("columnKeyMetaData").toString());
+        conf.set(
+            SchemaCryptoPropertiesFactory.PATH_NAME_PREFIX + columnKey,
+            cryptoMetadata
+                .get(columnShortName)
+                .get("columnKeyMetaData")
+                .toString());
       }
     }
   }
@@ -242,9 +265,12 @@ public class SchemaControlEncryptionTest {
 
     @Override
     protected WriteSupport<Group> getWriteSupport(Configuration conf) {
+      return getWriteSupport((ParquetConfiguration) null);
+    }
+
+    @Override
+    protected WriteSupport<Group> getWriteSupport(ParquetConfiguration conf) {
       return new CryptoGroupWriteSupport();
     }
   }
 }
-
-
