@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,18 +18,27 @@
  */
 package org.apache.parquet.filter2.recordlevel;
 
+import static org.apache.parquet.filter2.predicate.FilterApi.and;
+import static org.apache.parquet.filter2.predicate.FilterApi.binaryColumn;
+import static org.apache.parquet.filter2.predicate.FilterApi.doubleColumn;
+import static org.apache.parquet.filter2.predicate.FilterApi.eq;
+import static org.apache.parquet.filter2.predicate.FilterApi.gt;
+import static org.apache.parquet.filter2.predicate.FilterApi.in;
+import static org.apache.parquet.filter2.predicate.FilterApi.longColumn;
+import static org.apache.parquet.filter2.predicate.FilterApi.not;
+import static org.apache.parquet.filter2.predicate.FilterApi.notEq;
+import static org.apache.parquet.filter2.predicate.FilterApi.or;
+import static org.apache.parquet.filter2.predicate.FilterApi.userDefined;
+import static org.junit.Assert.assertEquals;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
-import java.util.HashSet;
-
-import org.junit.BeforeClass;
-import org.junit.Test;
-
 import org.apache.parquet.example.data.Group;
 import org.apache.parquet.filter2.compat.FilterCompat;
 import org.apache.parquet.filter2.predicate.FilterPredicate;
@@ -42,19 +51,8 @@ import org.apache.parquet.filter2.recordlevel.PhoneBookWriter.Location;
 import org.apache.parquet.filter2.recordlevel.PhoneBookWriter.PhoneNumber;
 import org.apache.parquet.filter2.recordlevel.PhoneBookWriter.User;
 import org.apache.parquet.io.api.Binary;
-
-import static org.junit.Assert.assertEquals;
-import static org.apache.parquet.filter2.predicate.FilterApi.and;
-import static org.apache.parquet.filter2.predicate.FilterApi.binaryColumn;
-import static org.apache.parquet.filter2.predicate.FilterApi.doubleColumn;
-import static org.apache.parquet.filter2.predicate.FilterApi.longColumn;
-import static org.apache.parquet.filter2.predicate.FilterApi.eq;
-import static org.apache.parquet.filter2.predicate.FilterApi.gt;
-import static org.apache.parquet.filter2.predicate.FilterApi.in;
-import static org.apache.parquet.filter2.predicate.FilterApi.not;
-import static org.apache.parquet.filter2.predicate.FilterApi.notEq;
-import static org.apache.parquet.filter2.predicate.FilterApi.or;
-import static org.apache.parquet.filter2.predicate.FilterApi.userDefined;
+import org.junit.BeforeClass;
+import org.junit.Test;
 
 public class TestRecordLevelFilters {
 
@@ -71,21 +69,24 @@ public class TestRecordLevelFilters {
 
     users.add(new User(27, "thing2", Arrays.asList(new PhoneNumber(1111111111L, "home")), null));
 
-    users.add(new User(28, "popular", Arrays.asList(
-        new PhoneNumber(1111111111L, "home"),
-        new PhoneNumber(2222222222L, null),
-        new PhoneNumber(3333333333L, "mobile")
-    ), null));
+    users.add(new User(
+        28,
+        "popular",
+        Arrays.asList(
+            new PhoneNumber(1111111111L, "home"),
+            new PhoneNumber(2222222222L, null),
+            new PhoneNumber(3333333333L, "mobile")),
+        null));
 
     users.add(new User(30, null, Arrays.asList(new PhoneNumber(1111111111L, "home")), null));
 
     for (int i = 100; i < 200; i++) {
       Location location = null;
       if (i % 3 == 1) {
-        location = new Location((double)i, (double)i*2);
+        location = new Location((double) i, (double) i * 2);
       }
       if (i % 3 == 2) {
-        location = new Location((double)i, null);
+        location = new Location((double) i, null);
       }
       users.add(new User(i, "p" + i, Arrays.asList(new PhoneNumber(i, "cell")), location));
     }
@@ -97,7 +98,7 @@ public class TestRecordLevelFilters {
   private static List<User> users;
 
   @BeforeClass
-  public static void setup() throws IOException{
+  public static void setup() throws IOException {
     users = makeUsers();
     phonebookFile = PhoneBookWriter.writeToFile(users);
   }
@@ -121,7 +122,7 @@ public class TestRecordLevelFilters {
     assertEquals(expected.size(), found.size());
     Iterator<Group> expectedIter = expected.iterator();
     Iterator<Group> foundIter = found.iterator();
-    while(expectedIter.hasNext()) {
+    while (expectedIter.hasNext()) {
       assertEquals(expectedIter.next().toString(), foundIter.next().toString());
     }
   }
@@ -172,12 +173,12 @@ public class TestRecordLevelFilters {
 
     // validate that all the values returned by the reader fulfills the filter and there are no values left out,
     // i.e. "thing1", "thing2" and from "p100" to "p199" and nothing else.
-    assertEquals(expectedNames.get(0), ((Group)(found.get(0))).getString("name", 0));
-    assertEquals(expectedNames.get(1), ((Group)(found.get(1))).getString("name", 0));
+    assertEquals(expectedNames.get(0), ((Group) (found.get(0))).getString("name", 0));
+    assertEquals(expectedNames.get(1), ((Group) (found.get(1))).getString("name", 0));
     for (int i = 2; i < 102; i++) {
-      assertEquals(expectedNames.get(i), ((Group)(found.get(i))).getString("name", 0));
+      assertEquals(expectedNames.get(i), ((Group) (found.get(i))).getString("name", 0));
     }
-    assert(found.size() == 102);
+    assert (found.size() == 102);
   }
 
   @Test
@@ -216,7 +217,7 @@ public class TestRecordLevelFilters {
       return false;
     }
   }
-  
+
   public static class SetInFilter extends UserDefinedPredicate<Long> implements Serializable {
 
     private HashSet<Long> hSet;
@@ -260,7 +261,7 @@ public class TestRecordLevelFilters {
       }
     });
   }
-  
+
   @Test
   public void testUserDefinedByInstance() throws Exception {
     LongColumn name = longColumn("id");
@@ -269,7 +270,7 @@ public class TestRecordLevelFilters {
     h.add(20L);
     h.add(27L);
     h.add(28L);
-    
+
     FilterPredicate pred = userDefined(name, new SetInFilter(h));
 
     List<Group> found = PhoneBookWriter.readFile(phonebookFile, FilterCompat.get(pred));
